about summary refs log tree commit diff
path: root/other/pamx/window.c
diff options
context:
space:
mode:
authorgiraffedata <giraffedata@9d0c8265-081b-0410-96cb-a4ca84ce46f8>2014-06-29 19:32:13 +0000
committergiraffedata <giraffedata@9d0c8265-081b-0410-96cb-a4ca84ce46f8>2014-06-29 19:32:13 +0000
commit51eb5e0d2722f0cf1033ac158d2fdbcd82b6e800 (patch)
tree3b763ebf105fc1136ebcac13b7d4dafca114be68 /other/pamx/window.c
parent1610a1f6aa54ad1d97926c1d8605720933059df7 (diff)
downloadnetpbm-mirror-51eb5e0d2722f0cf1033ac158d2fdbcd82b6e800.tar.gz
netpbm-mirror-51eb5e0d2722f0cf1033ac158d2fdbcd82b6e800.tar.xz
netpbm-mirror-51eb5e0d2722f0cf1033ac158d2fdbcd82b6e800.zip
Reverse messed up commit
git-svn-id: http://svn.code.sf.net/p/netpbm/code/advanced@2222 9d0c8265-081b-0410-96cb-a4ca84ce46f8
Diffstat (limited to 'other/pamx/window.c')
-rw-r--r--other/pamx/window.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/other/pamx/window.c b/other/pamx/window.c
index 3cded1b3..ec2a77fe 100644
--- a/other/pamx/window.c
+++ b/other/pamx/window.c
@@ -193,7 +193,7 @@ determineRepaintStrategy(viewer  *    const viewerP,
                         
     /* Decide how we're going to handle repaints.  We have three modes:
        use backing-store, use background pixmap, and use exposures.
-       If the server allows backing-store, we enable it and use it.
+       If the server supports backing-store, we enable it and use it.
        This really helps servers which are memory constrained.  If the
        server does not have backing-store, we try to send the image to
        a pixmap and use that as backing-store.  If that fails, we use
@@ -652,9 +652,9 @@ bestVisual(Display *      const disp,
     Visual * visualP;
     Visual * default_visualP;
 
-    /* Figure out the best depth the server allows.  note that some servers
-       (such as the HP 11.3 server) actually say they allow some depths but
-       have no visuals that allow that depth.  Seems silly to me ...
+    /* Figure out the best depth the server supports.  note that some servers
+       (such as the HP 11.3 server) actually say they support some depths but
+       have no visuals that support that depth.  Seems silly to me ...
     */
 
     depth = 0;